mario\_addons.plugins package
=============================

Submodules
----------

mario\_addons.plugins.read module
---------------------------------

.. automodule:: mario_addons.plugins.read
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: mario_addons.plugins
   :members:
   :undoc-members:
   :show-inheritance:
